/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2007 - INRIA - Allan CORNET
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

#ifndef __INITIALIZELOCALIZATION_H__
#define __INITIALIZELOCALIZATION_H__
#include "dynlib_localization.h"
#include "BOOL.h"

LOCALIZATION_IMPEXP BOOL InitializeLocalization(void);

#endif /* __INITIALIZELOCALIZATION_H__ */
/*--------------------------------------------------------------------------*/ 
